# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: boltlight_proto/boltlight.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='boltlight_proto/boltlight.proto',
  package='boltlight',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1f\x62oltlight_proto/boltlight.proto\x12\tboltlight\"6\n\rUnlockRequest\x12\x10\n\x08password\x18\x01 \x01(\t\x12\x13\n\x0bunlock_node\x18\x02 \x01(\x08\"\'\n\x0eUnlockResponse\x12\x15\n\rnode_unlocked\x18\x01 \x01(\x08\"\x10\n\x0eGetInfoRequest\"U\n\x0fGetInfoResponse\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x1b\n\x13node_implementation\x18\x02 \x01(\t\x12\x14\n\x0cnode_version\x18\x03 \x01(\t\"\r\n\x0bLockRequest\"\x0e\n\x0cLockResponse\"\x18\n\x16\x42\x61lanceOffChainRequest\"w\n\x17\x42\x61lanceOffChainResponse\x12\x14\n\x0cout_tot_msat\x18\x01 \x01(\x04\x12\x18\n\x10out_tot_now_msat\x18\x02 \x01(\x04\x12\x13\n\x0bin_tot_msat\x18\x04 \x01(\x04\x12\x17\n\x0fin_tot_now_msat\x18\x05 \x01(\x04\"+\n\x13\x43heckInvoiceRequest\x12\x14\n\x0cpayment_hash\x18\x01 \x01(\t\"?\n\x14\x43heckInvoiceResponse\x12\'\n\x05state\x18\x01 \x01(\x0e\x32\x18.boltlight.Invoice.State\"8\n\x13\x43loseChannelRequest\x12\x12\n\nchannel_id\x18\x01 \x01(\t\x12\r\n\x05\x66orce\x18\x02 \x01(\x08\",\n\x14\x43loseChannelResponse\x12\x14\n\x0c\x63losing_txid\x18\x01 \x01(\t\"\x86\x01\n\x14\x43reateInvoiceRequest\x12\x13\n\x0b\x61mount_msat\x18\x01 \x01(\x04\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06\x65xpiry\x18\x03 \x01(\r\x12\x1d\n\x15min_final_cltv_expiry\x18\x04 \x01(\r\x12\x15\n\rfallback_addr\x18\x05 \x01(\t\"Z\n\x15\x43reateInvoiceResponse\x12\x17\n\x0fpayment_request\x18\x01 \x01(\t\x12\x14\n\x0cpayment_hash\x18\x02 \x01(\t\x12\x12\n\nexpires_at\x18\x03 \x01(\x04\"\x14\n\x12GetNodeInfoRequest\"D\n\x14\x44\x65\x63odeInvoiceRequest\x12\x17\n\x0fpayment_request\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\"\x91\x02\n\x15\x44\x65\x63odeInvoiceResponse\x12\x13\n\x0b\x61mount_msat\x18\x01 \x01(\x04\x12\x14\n\x0cpayment_hash\x18\x02 \x01(\t\x12\x1a\n\x12\x64\x65stination_pubkey\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x18\n\x10\x64\x65scription_hash\x18\x05 \x01(\t\x12\x11\n\ttimestamp\x18\x06 \x01(\x04\x12\x0e\n\x06\x65xpiry\x18\x07 \x01(\r\x12\x1d\n\x15min_final_cltv_expiry\x18\x08 \x01(\r\x12\x15\n\rfallback_addr\x18\t \x01(\t\x12)\n\x0broute_hints\x18\n \x03(\x0b\x32\x14.boltlight.RouteHint\"2\n\tRouteHint\x12%\n\thop_hints\x18\x01 \x03(\x0b\x32\x12.boltlight.HopHint\"\x8a\x01\n\x07HopHint\x12\x0e\n\x06pubkey\x18\x01 \x01(\t\x12\x18\n\x10short_channel_id\x18\x02 \x01(\t\x12\x15\n\rfee_base_msat\x18\x03 \x01(\r\x12#\n\x1b\x66\x65\x65_proportional_millionths\x18\x04 \x01(\r\x12\x19\n\x11\x63ltv_expiry_delta\x18\x05 \x01(\r\"E\n\x07Network\":\n\x04Name\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07MAINNET\x10\x01\x12\x0b\n\x07TESTNET\x10\x02\x12\x0b\n\x07REGTEST\x10\x03\"\x9e\x01\n\x13GetNodeInfoResponse\x12\x10\n\x08node_uri\x18\x01 \x01(\t\x12\x17\n\x0fidentity_pubkey\x18\x02 \x01(\t\x12\r\n\x05\x61lias\x18\x03 \x01(\t\x12\r\n\x05\x63olor\x18\x04 \x01(\t\x12\x14\n\x0c\x62lock_height\x18\x05 \x01(\r\x12(\n\x07network\x18\x06 \x01(\x0e\x32\x17.boltlight.Network.Name\"*\n\x13ListChannelsRequest\x12\x13\n\x0b\x61\x63tive_only\x18\x01 \x01(\x08\"<\n\x14ListChannelsResponse\x12$\n\x08\x63hannels\x18\x01 \x03(\x0b\x32\x12.boltlight.Channel\"\xb1\x03\n\x07\x43hannel\x12\x15\n\rremote_pubkey\x18\x01 \x01(\t\x12\x18\n\x10short_channel_id\x18\x02 \x01(\t\x12\x12\n\nchannel_id\x18\x03 \x01(\t\x12\x14\n\x0c\x66unding_txid\x18\x04 \x01(\t\x12\x15\n\rcapacity_msat\x18\x05 \x01(\x04\x12\x1a\n\x12local_balance_msat\x18\x06 \x01(\x04\x12\x1b\n\x13remote_balance_msat\x18\x07 \x01(\x04\x12\x19\n\x11local_reserve_sat\x18\x08 \x01(\x04\x12\x1a\n\x12remote_reserve_sat\x18\t \x01(\x04\x12\x15\n\rto_self_delay\x18\n \x01(\r\x12\x0f\n\x07private\x18\x0b \x01(\x08\x12\'\n\x05state\x18\x0c \x01(\x0e\x32\x18.boltlight.Channel.State\x12\x0e\n\x06\x61\x63tive\x18\r \x01(\x08\"c\n\x05State\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x10\n\x0cPENDING_OPEN\x10\x01\x12\x08\n\x04OPEN\x10\x02\x12\x18\n\x14PENDING_MUTUAL_CLOSE\x10\x03\x12\x17\n\x13PENDING_FORCE_CLOSE\x10\x04\"\xe5\x01\n\x13ListInvoicesRequest\x12\x11\n\tmax_items\x18\x01 \x01(\r\x12\x18\n\x10search_timestamp\x18\x02 \x01(\x04\x12\x30\n\x0csearch_order\x18\x03 \x01(\x0e\x32\x1a.boltlight.Order.Direction\x12.\n\nlist_order\x18\x04 \x01(\x0e\x32\x1a.boltlight.Order.Direction\x12\x0c\n\x04paid\x18\x05 \x01(\x08\x12\x0f\n\x07pending\x18\x06 \x01(\x08\x12\x0f\n\x07\x65xpired\x18\x07 \x01(\x08\x12\x0f\n\x07unknown\x18\x08 \x01(\x08\"<\n\x14ListInvoicesResponse\x12$\n\x08invoices\x18\x01 \x03(\x0b\x32\x12.boltlight.Invoice\"3\n\x05Order\"*\n\tDirection\x12\r\n\tASCENDING\x10\x00\x12\x0e\n\nDESCENDING\x10\x01\"\xea\x02\n\x07Invoice\x12\x1b\n\x13\x61mount_encoded_msat\x18\x01 \x01(\x04\x12\x1c\n\x14\x61mount_received_msat\x18\x02 \x01(\x04\x12\x14\n\x0cpayment_hash\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x18\n\x10\x64\x65scription_hash\x18\x05 \x01(\t\x12\x11\n\ttimestamp\x18\x06 \x01(\x04\x12\x0e\n\x06\x65xpiry\x18\x07 \x01(\r\x12\x15\n\rfallback_addr\x18\x08 \x01(\t\x12)\n\x0broute_hints\x18\t \x03(\x0b\x32\x14.boltlight.RouteHint\x12\'\n\x05state\x18\n \x01(\x0e\x32\x18.boltlight.Invoice.State\x12\x17\n\x0fpayment_request\x18\x0b \x01(\t\"8\n\x05State\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04PAID\x10\x01\x12\x0b\n\x07PENDING\x10\x02\x12\x0b\n\x07\x45XPIRED\x10\x03\"\x15\n\x13ListPaymentsRequest\"<\n\x14ListPaymentsResponse\x12$\n\x08payments\x18\x01 \x03(\x0b\x32\x12.boltlight.Payment\"s\n\x07Payment\x12\x13\n\x0b\x61mount_msat\x18\x01 \x01(\x04\x12\x11\n\ttimestamp\x18\x02 \x01(\x04\x12\x14\n\x0cpayment_hash\x18\x03 \x01(\t\x12\x18\n\x10payment_preimage\x18\x04 \x01(\t\x12\x10\n\x08\x66\x65\x65_msat\x18\x05 \x01(\x04\"\x12\n\x10ListPeersRequest\"3\n\x11ListPeersResponse\x12\x1e\n\x05peers\x18\x01 \x03(\x0b\x32\x0f.boltlight.Peer\"E\n\x04Peer\x12\x0e\n\x06pubkey\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\x12\r\n\x05\x61lias\x18\x03 \x01(\t\x12\r\n\x05\x63olor\x18\x04 \x01(\t\"\x19\n\x17ListTransactionsRequest\"H\n\x18ListTransactionsResponse\x12,\n\x0ctransactions\x18\x01 \x03(\x0b\x32\x16.boltlight.Transaction\"\x94\x01\n\x0bTransaction\x12\x12\n\namount_sat\x18\x01 \x01(\x03\x12\x0c\n\x04txid\x18\x02 \x01(\t\x12\x15\n\rconfirmations\x18\x03 \x01(\r\x12\x14\n\x0c\x62lock_height\x18\x04 \x01(\r\x12\x12\n\nblock_hash\x18\x05 \x01(\t\x12\x11\n\ttimestamp\x18\x06 \x01(\x04\x12\x0f\n\x07\x66\x65\x65_sat\x18\x07 \x01(\x04\"?\n\x11NewAddressRequest\x12*\n\taddr_type\x18\x01 \x01(\x0e\x32\x17.boltlight.Address.Type\"%\n\x12NewAddressResponse\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"T\n\x07\x41\x64\x64ress\"I\n\x04Type\x12\n\n\x06P2WPKH\x10\x00\x12\x11\n\rNATIVE_SEGWIT\x10\x00\x12\x0b\n\x07NP2WPKH\x10\x01\x12\x11\n\rNESTED_SEGWIT\x10\x01\x1a\x02\x10\x01\"_\n\x12OpenChannelRequest\x12\x10\n\x08node_uri\x18\x01 \x01(\t\x12\x13\n\x0b\x66unding_sat\x18\x02 \x01(\x04\x12\x11\n\tpush_msat\x18\x03 \x01(\x04\x12\x0f\n\x07private\x18\x04 \x01(\x08\"+\n\x13OpenChannelResponse\x12\x14\n\x0c\x66unding_txid\x18\x01 \x01(\t\"q\n\x11PayInvoiceRequest\x12\x17\n\x0fpayment_request\x18\x01 \x01(\t\x12\x13\n\x0b\x61mount_msat\x18\x02 \x01(\x04\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x19\n\x11\x63ltv_expiry_delta\x18\x04 \x01(\r\".\n\x12PayInvoiceResponse\x12\x18\n\x10payment_preimage\x18\x01 \x01(\t\"N\n\x11PayOnChainRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x12\n\namount_sat\x18\x02 \x01(\x04\x12\x14\n\x0c\x66\x65\x65_sat_byte\x18\x03 \x01(\r\"\"\n\x12PayOnChainResponse\x12\x0c\n\x04txid\x18\x01 \x01(\t\"%\n\x11UnlockNodeRequest\x12\x10\n\x08password\x18\x01 \x01(\t\"\x14\n\x12UnlockNodeResponse\"\x17\n\x15\x42\x61lanceOnChainRequest\"B\n\x16\x42\x61lanceOnChainResponse\x12\x15\n\rconfirmed_sat\x18\x01 \x01(\x04\x12\x11\n\ttotal_sat\x18\x02 \x01(\x04\x32I\n\x08Unlocker\x12=\n\x06Unlock\x12\x18.boltlight.UnlockRequest\x1a\x19.boltlight.UnlockResponse2\x86\x01\n\tBoltlight\x12@\n\x07GetInfo\x12\x19.boltlight.GetInfoRequest\x1a\x1a.boltlight.GetInfoResponse\x12\x37\n\x04Lock\x12\x16.boltlight.LockRequest\x1a\x17.boltlight.LockResponse2\xe6\n\n\tLightning\x12X\n\x0f\x42\x61lanceOffChain\x12!.boltlight.BalanceOffChainRequest\x1a\".boltlight.BalanceOffChainResponse\x12U\n\x0e\x42\x61lanceOnChain\x12 .boltlight.BalanceOnChainRequest\x1a!.boltlight.BalanceOnChainResponse\x12O\n\x0c\x43heckInvoice\x12\x1e.boltlight.CheckInvoiceRequest\x1a\x1f.boltlight.CheckInvoiceResponse\x12O\n\x0c\x43loseChannel\x12\x1e.boltlight.CloseChannelRequest\x1a\x1f.boltlight.CloseChannelResponse\x12R\n\rCreateInvoice\x12\x1f.boltlight.CreateInvoiceRequest\x1a .boltlight.CreateInvoiceResponse\x12R\n\rDecodeInvoice\x12\x1f.boltlight.DecodeInvoiceRequest\x1a .boltlight.DecodeInvoiceResponse\x12L\n\x0bGetNodeInfo\x12\x1d.boltlight.GetNodeInfoRequest\x1a\x1e.boltlight.GetNodeInfoResponse\x12O\n\x0cListChannels\x12\x1e.boltlight.ListChannelsRequest\x1a\x1f.boltlight.ListChannelsResponse\x12O\n\x0cListInvoices\x12\x1e.boltlight.ListInvoicesRequest\x1a\x1f.boltlight.ListInvoicesResponse\x12O\n\x0cListPayments\x12\x1e.boltlight.ListPaymentsRequest\x1a\x1f.boltlight.ListPaymentsResponse\x12\x46\n\tListPeers\x12\x1b.boltlight.ListPeersRequest\x1a\x1c.boltlight.ListPeersResponse\x12[\n\x10ListTransactions\x12\".boltlight.ListTransactionsRequest\x1a#.boltlight.ListTransactionsResponse\x12I\n\nNewAddress\x12\x1c.boltlight.NewAddressRequest\x1a\x1d.boltlight.NewAddressResponse\x12L\n\x0bOpenChannel\x12\x1d.boltlight.OpenChannelRequest\x1a\x1e.boltlight.OpenChannelResponse\x12I\n\nPayInvoice\x12\x1c.boltlight.PayInvoiceRequest\x1a\x1d.boltlight.PayInvoiceResponse\x12I\n\nPayOnChain\x12\x1c.boltlight.PayOnChainRequest\x1a\x1d.boltlight.PayOnChainResponse\x12I\n\nUnlockNode\x12\x1c.boltlight.UnlockNodeRequest\x1a\x1d.boltlight.UnlockNodeResponseb\x06proto3'
)



_NETWORK_NAME = _descriptor.EnumDescriptor(
  name='Name',
  full_name='boltlight.Network.Name',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MAINNET', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TESTNET', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REGTEST', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1441,
  serialized_end=1499,
)
_sym_db.RegisterEnumDescriptor(_NETWORK_NAME)

_CHANNEL_STATE = _descriptor.EnumDescriptor(
  name='State',
  full_name='boltlight.Channel.State',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PENDING_OPEN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OPEN', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PENDING_MUTUAL_CLOSE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PENDING_FORCE_CLOSE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2103,
  serialized_end=2202,
)
_sym_db.RegisterEnumDescriptor(_CHANNEL_STATE)

_ORDER_DIRECTION = _descriptor.EnumDescriptor(
  name='Direction',
  full_name='boltlight.Order.Direction',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ASCENDING', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DESCENDING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2507,
  serialized_end=2549,
)
_sym_db.RegisterEnumDescriptor(_ORDER_DIRECTION)

_INVOICE_STATE = _descriptor.EnumDescriptor(
  name='State',
  full_name='boltlight.Invoice.State',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PAID', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PENDING', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXPIRED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2858,
  serialized_end=2914,
)
_sym_db.RegisterEnumDescriptor(_INVOICE_STATE)

_ADDRESS_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='boltlight.Address.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='P2WPKH', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NATIVE_SEGWIT', index=1, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NP2WPKH', index=2, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NESTED_SEGWIT', index=3, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=b'\020\001',
  serialized_start=3629,
  serialized_end=3702,
)
_sym_db.RegisterEnumDescriptor(_ADDRESS_TYPE)


_UNLOCKREQUEST = _descriptor.Descriptor(
  name='UnlockRequest',
  full_name='boltlight.UnlockRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='password', full_name='boltlight.UnlockRequest.password', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unlock_node', full_name='boltlight.UnlockRequest.unlock_node', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=46,
  serialized_end=100,
)


_UNLOCKRESPONSE = _descriptor.Descriptor(
  name='UnlockResponse',
  full_name='boltlight.UnlockResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_unlocked', full_name='boltlight.UnlockResponse.node_unlocked', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=102,
  serialized_end=141,
)


_GETINFOREQUEST = _descriptor.Descriptor(
  name='GetInfoRequest',
  full_name='boltlight.GetInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=143,
  serialized_end=159,
)


_GETINFORESPONSE = _descriptor.Descriptor(
  name='GetInfoResponse',
  full_name='boltlight.GetInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='boltlight.GetInfoResponse.version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_implementation', full_name='boltlight.GetInfoResponse.node_implementation', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_version', full_name='boltlight.GetInfoResponse.node_version', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=161,
  serialized_end=246,
)


_LOCKREQUEST = _descriptor.Descriptor(
  name='LockRequest',
  full_name='boltlight.LockRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=248,
  serialized_end=261,
)


_LOCKRESPONSE = _descriptor.Descriptor(
  name='LockResponse',
  full_name='boltlight.LockResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=263,
  serialized_end=277,
)


_BALANCEOFFCHAINREQUEST = _descriptor.Descriptor(
  name='BalanceOffChainRequest',
  full_name='boltlight.BalanceOffChainRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=279,
  serialized_end=303,
)


_BALANCEOFFCHAINRESPONSE = _descriptor.Descriptor(
  name='BalanceOffChainResponse',
  full_name='boltlight.BalanceOffChainResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='out_tot_msat', full_name='boltlight.BalanceOffChainResponse.out_tot_msat', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='out_tot_now_msat', full_name='boltlight.BalanceOffChainResponse.out_tot_now_msat', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='in_tot_msat', full_name='boltlight.BalanceOffChainResponse.in_tot_msat', index=2,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='in_tot_now_msat', full_name='boltlight.BalanceOffChainResponse.in_tot_now_msat', index=3,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=305,
  serialized_end=424,
)


_CHECKINVOICEREQUEST = _descriptor.Descriptor(
  name='CheckInvoiceRequest',
  full_name='boltlight.CheckInvoiceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='payment_hash', full_name='boltlight.CheckInvoiceRequest.payment_hash', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=426,
  serialized_end=469,
)


_CHECKINVOICERESPONSE = _descriptor.Descriptor(
  name='CheckInvoiceResponse',
  full_name='boltlight.CheckInvoiceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='boltlight.CheckInvoiceResponse.state', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=471,
  serialized_end=534,
)


_CLOSECHANNELREQUEST = _descriptor.Descriptor(
  name='CloseChannelRequest',
  full_name='boltlight.CloseChannelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel_id', full_name='boltlight.CloseChannelRequest.channel_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='force', full_name='boltlight.CloseChannelRequest.force', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=536,
  serialized_end=592,
)


_CLOSECHANNELRESPONSE = _descriptor.Descriptor(
  name='CloseChannelResponse',
  full_name='boltlight.CloseChannelResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='closing_txid', full_name='boltlight.CloseChannelResponse.closing_txid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=594,
  serialized_end=638,
)


_CREATEINVOICEREQUEST = _descriptor.Descriptor(
  name='CreateInvoiceRequest',
  full_name='boltlight.CreateInvoiceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='amount_msat', full_name='boltlight.CreateInvoiceRequest.amount_msat', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='boltlight.CreateInvoiceRequest.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expiry', full_name='boltlight.CreateInvoiceRequest.expiry', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_final_cltv_expiry', full_name='boltlight.CreateInvoiceRequest.min_final_cltv_expiry', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fallback_addr', full_name='boltlight.CreateInvoiceRequest.fallback_addr', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=641,
  serialized_end=775,
)


_CREATEINVOICERESPONSE = _descriptor.Descriptor(
  name='CreateInvoiceResponse',
  full_name='boltlight.CreateInvoiceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='payment_request', full_name='boltlight.CreateInvoiceResponse.payment_request', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payment_hash', full_name='boltlight.CreateInvoiceResponse.payment_hash', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expires_at', full_name='boltlight.CreateInvoiceResponse.expires_at', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=777,
  serialized_end=867,
)


_GETNODEINFOREQUEST = _descriptor.Descriptor(
  name='GetNodeInfoRequest',
  full_name='boltlight.GetNodeInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=869,
  serialized_end=889,
)


_DECODEINVOICEREQUEST = _descriptor.Descriptor(
  name='DecodeInvoiceRequest',
  full_name='boltlight.DecodeInvoiceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='payment_request', full_name='boltlight.DecodeInvoiceRequest.payment_request', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='boltlight.DecodeInvoiceRequest.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=891,
  serialized_end=959,
)


_DECODEINVOICERESPONSE = _descriptor.Descriptor(
  name='DecodeInvoiceResponse',
  full_name='boltlight.DecodeInvoiceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='amount_msat', full_name='boltlight.DecodeInvoiceResponse.amount_msat', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payment_hash', full_name='boltlight.DecodeInvoiceResponse.payment_hash', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destination_pubkey', full_name='boltlight.DecodeInvoiceResponse.destination_pubkey', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='boltlight.DecodeInvoiceResponse.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description_hash', full_name='boltlight.DecodeInvoiceResponse.description_hash', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='boltlight.DecodeInvoiceResponse.timestamp', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expiry', full_name='boltlight.DecodeInvoiceResponse.expiry', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_final_cltv_expiry', full_name='boltlight.DecodeInvoiceResponse.min_final_cltv_expiry', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fallback_addr', full_name='boltlight.DecodeInvoiceResponse.fallback_addr', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='route_hints', full_name='boltlight.DecodeInvoiceResponse.route_hints', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=962,
  serialized_end=1235,
)


_ROUTEHINT = _descriptor.Descriptor(
  name='RouteHint',
  full_name='boltlight.RouteHint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hop_hints', full_name='boltlight.RouteHint.hop_hints', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1237,
  serialized_end=1287,
)


_HOPHINT = _descriptor.Descriptor(
  name='HopHint',
  full_name='boltlight.HopHint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pubkey', full_name='boltlight.HopHint.pubkey', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='short_channel_id', full_name='boltlight.HopHint.short_channel_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fee_base_msat', full_name='boltlight.HopHint.fee_base_msat', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fee_proportional_millionths', full_name='boltlight.HopHint.fee_proportional_millionths', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cltv_expiry_delta', full_name='boltlight.HopHint.cltv_expiry_delta', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1290,
  serialized_end=1428,
)


_NETWORK = _descriptor.Descriptor(
  name='Network',
  full_name='boltlight.Network',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _NETWORK_NAME,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1430,
  serialized_end=1499,
)


_GETNODEINFORESPONSE = _descriptor.Descriptor(
  name='GetNodeInfoResponse',
  full_name='boltlight.GetNodeInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_uri', full_name='boltlight.GetNodeInfoResponse.node_uri', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='identity_pubkey', full_name='boltlight.GetNodeInfoResponse.identity_pubkey', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='alias', full_name='boltlight.GetNodeInfoResponse.alias', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='color', full_name='boltlight.GetNodeInfoResponse.color', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='block_height', full_name='boltlight.GetNodeInfoResponse.block_height', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='network', full_name='boltlight.GetNodeInfoResponse.network', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1502,
  serialized_end=1660,
)


_LISTCHANNELSREQUEST = _descriptor.Descriptor(
  name='ListChannelsRequest',
  full_name='boltlight.ListChannelsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='active_only', full_name='boltlight.ListChannelsRequest.active_only', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1662,
  serialized_end=1704,
)


_LISTCHANNELSRESPONSE = _descriptor.Descriptor(
  name='ListChannelsResponse',
  full_name='boltlight.ListChannelsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='channels', full_name='boltlight.ListChannelsResponse.channels', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1706,
  serialized_end=1766,
)


_CHANNEL = _descriptor.Descriptor(
  name='Channel',
  full_name='boltlight.Channel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='remote_pubkey', full_name='boltlight.Channel.remote_pubkey', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='short_channel_id', full_name='boltlight.Channel.short_channel_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_id', full_name='boltlight.Channel.channel_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='funding_txid', full_name='boltlight.Channel.funding_txid', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='capacity_msat', full_name='boltlight.Channel.capacity_msat', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='local_balance_msat', full_name='boltlight.Channel.local_balance_msat', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remote_balance_msat', full_name='boltlight.Channel.remote_balance_msat', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='local_reserve_sat', full_name='boltlight.Channel.local_reserve_sat', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remote_reserve_sat', full_name='boltlight.Channel.remote_reserve_sat', index=8,
      number=9, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='to_self_delay', full_name='boltlight.Channel.to_self_delay', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='private', full_name='boltlight.Channel.private', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='boltlight.Channel.state', index=11,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='active', full_name='boltlight.Channel.active', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CHANNEL_STATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1769,
  serialized_end=2202,
)


_LISTINVOICESREQUEST = _descriptor.Descriptor(
  name='ListInvoicesRequest',
  full_name='boltlight.ListInvoicesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_items', full_name='boltlight.ListInvoicesRequest.max_items', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='search_timestamp', full_name='boltlight.ListInvoicesRequest.search_timestamp', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='search_order', full_name='boltlight.ListInvoicesRequest.search_order', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='list_order', full_name='boltlight.ListInvoicesRequest.list_order', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='paid', full_name='boltlight.ListInvoicesRequest.paid', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pending', full_name='boltlight.ListInvoicesRequest.pending', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expired', full_name='boltlight.ListInvoicesRequest.expired', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unknown', full_name='boltlight.ListInvoicesRequest.unknown', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2205,
  serialized_end=2434,
)


_LISTINVOICESRESPONSE = _descriptor.Descriptor(
  name='ListInvoicesResponse',
  full_name='boltlight.ListInvoicesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='invoices', full_name='boltlight.ListInvoicesResponse.invoices', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2436,
  serialized_end=2496,
)


_ORDER = _descriptor.Descriptor(
  name='Order',
  full_name='boltlight.Order',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ORDER_DIRECTION,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2498,
  serialized_end=2549,
)


_INVOICE = _descriptor.Descriptor(
  name='Invoice',
  full_name='boltlight.Invoice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='amount_encoded_msat', full_name='boltlight.Invoice.amount_encoded_msat', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount_received_msat', full_name='boltlight.Invoice.amount_received_msat', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payment_hash', full_name='boltlight.Invoice.payment_hash', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='boltlight.Invoice.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description_hash', full_name='boltlight.Invoice.description_hash', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='boltlight.Invoice.timestamp', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expiry', full_name='boltlight.Invoice.expiry', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fallback_addr', full_name='boltlight.Invoice.fallback_addr', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='route_hints', full_name='boltlight.Invoice.route_hints', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='boltlight.Invoice.state', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payment_request', full_name='boltlight.Invoice.payment_request', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _INVOICE_STATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2552,
  serialized_end=2914,
)


_LISTPAYMENTSREQUEST = _descriptor.Descriptor(
  name='ListPaymentsRequest',
  full_name='boltlight.ListPaymentsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2916,
  serialized_end=2937,
)


_LISTPAYMENTSRESPONSE = _descriptor.Descriptor(
  name='ListPaymentsResponse',
  full_name='boltlight.ListPaymentsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='payments', full_name='boltlight.ListPaymentsResponse.payments', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2939,
  serialized_end=2999,
)


_PAYMENT = _descriptor.Descriptor(
  name='Payment',
  full_name='boltlight.Payment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='amount_msat', full_name='boltlight.Payment.amount_msat', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='boltlight.Payment.timestamp', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payment_hash', full_name='boltlight.Payment.payment_hash', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payment_preimage', full_name='boltlight.Payment.payment_preimage', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fee_msat', full_name='boltlight.Payment.fee_msat', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3001,
  serialized_end=3116,
)


_LISTPEERSREQUEST = _descriptor.Descriptor(
  name='ListPeersRequest',
  full_name='boltlight.ListPeersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3118,
  serialized_end=3136,
)


_LISTPEERSRESPONSE = _descriptor.Descriptor(
  name='ListPeersResponse',
  full_name='boltlight.ListPeersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='peers', full_name='boltlight.ListPeersResponse.peers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3138,
  serialized_end=3189,
)


_PEER = _descriptor.Descriptor(
  name='Peer',
  full_name='boltlight.Peer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pubkey', full_name='boltlight.Peer.pubkey', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='address', full_name='boltlight.Peer.address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='alias', full_name='boltlight.Peer.alias', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='color', full_name='boltlight.Peer.color', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3191,
  serialized_end=3260,
)


_LISTTRANSACTIONSREQUEST = _descriptor.Descriptor(
  name='ListTransactionsRequest',
  full_name='boltlight.ListTransactionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3262,
  serialized_end=3287,
)


_LISTTRANSACTIONSRESPONSE = _descriptor.Descriptor(
  name='ListTransactionsResponse',
  full_name='boltlight.ListTransactionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transactions', full_name='boltlight.ListTransactionsResponse.transactions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3289,
  serialized_end=3361,
)


_TRANSACTION = _descriptor.Descriptor(
  name='Transaction',
  full_name='boltlight.Transaction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='amount_sat', full_name='boltlight.Transaction.amount_sat', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='txid', full_name='boltlight.Transaction.txid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='confirmations', full_name='boltlight.Transaction.confirmations', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='block_height', full_name='boltlight.Transaction.block_height', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='block_hash', full_name='boltlight.Transaction.block_hash', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='boltlight.Transaction.timestamp', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fee_sat', full_name='boltlight.Transaction.fee_sat', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3364,
  serialized_end=3512,
)


_NEWADDRESSREQUEST = _descriptor.Descriptor(
  name='NewAddressRequest',
  full_name='boltlight.NewAddressRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='addr_type', full_name='boltlight.NewAddressRequest.addr_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3514,
  serialized_end=3577,
)


_NEWADDRESSRESPONSE = _descriptor.Descriptor(
  name='NewAddressResponse',
  full_name='boltlight.NewAddressResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='boltlight.NewAddressResponse.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3579,
  serialized_end=3616,
)


_ADDRESS = _descriptor.Descriptor(
  name='Address',
  full_name='boltlight.Address',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ADDRESS_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3618,
  serialized_end=3702,
)


_OPENCHANNELREQUEST = _descriptor.Descriptor(
  name='OpenChannelRequest',
  full_name='boltlight.OpenChannelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_uri', full_name='boltlight.OpenChannelRequest.node_uri', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='funding_sat', full_name='boltlight.OpenChannelRequest.funding_sat', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='push_msat', full_name='boltlight.OpenChannelRequest.push_msat', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='private', full_name='boltlight.OpenChannelRequest.private', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3704,
  serialized_end=3799,
)


_OPENCHANNELRESPONSE = _descriptor.Descriptor(
  name='OpenChannelResponse',
  full_name='boltlight.OpenChannelResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='funding_txid', full_name='boltlight.OpenChannelResponse.funding_txid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3801,
  serialized_end=3844,
)


_PAYINVOICEREQUEST = _descriptor.Descriptor(
  name='PayInvoiceRequest',
  full_name='boltlight.PayInvoiceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='payment_request', full_name='boltlight.PayInvoiceRequest.payment_request', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount_msat', full_name='boltlight.PayInvoiceRequest.amount_msat', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='boltlight.PayInvoiceRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cltv_expiry_delta', full_name='boltlight.PayInvoiceRequest.cltv_expiry_delta', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3846,
  serialized_end=3959,
)


_PAYINVOICERESPONSE = _descriptor.Descriptor(
  name='PayInvoiceResponse',
  full_name='boltlight.PayInvoiceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='payment_preimage', full_name='boltlight.PayInvoiceResponse.payment_preimage', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3961,
  serialized_end=4007,
)


_PAYONCHAINREQUEST = _descriptor.Descriptor(
  name='PayOnChainRequest',
  full_name='boltlight.PayOnChainRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='boltlight.PayOnChainRequest.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount_sat', full_name='boltlight.PayOnChainRequest.amount_sat', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fee_sat_byte', full_name='boltlight.PayOnChainRequest.fee_sat_byte', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4009,
  serialized_end=4087,
)


_PAYONCHAINRESPONSE = _descriptor.Descriptor(
  name='PayOnChainResponse',
  full_name='boltlight.PayOnChainResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='txid', full_name='boltlight.PayOnChainResponse.txid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4089,
  serialized_end=4123,
)


_UNLOCKNODEREQUEST = _descriptor.Descriptor(
  name='UnlockNodeRequest',
  full_name='boltlight.UnlockNodeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='password', full_name='boltlight.UnlockNodeRequest.password', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4125,
  serialized_end=4162,
)


_UNLOCKNODERESPONSE = _descriptor.Descriptor(
  name='UnlockNodeResponse',
  full_name='boltlight.UnlockNodeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4164,
  serialized_end=4184,
)


_BALANCEONCHAINREQUEST = _descriptor.Descriptor(
  name='BalanceOnChainRequest',
  full_name='boltlight.BalanceOnChainRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4186,
  serialized_end=4209,
)


_BALANCEONCHAINRESPONSE = _descriptor.Descriptor(
  name='BalanceOnChainResponse',
  full_name='boltlight.BalanceOnChainResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='confirmed_sat', full_name='boltlight.BalanceOnChainResponse.confirmed_sat', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_sat', full_name='boltlight.BalanceOnChainResponse.total_sat', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4211,
  serialized_end=4277,
)

_CHECKINVOICERESPONSE.fields_by_name['state'].enum_type = _INVOICE_STATE
_DECODEINVOICERESPONSE.fields_by_name['route_hints'].message_type = _ROUTEHINT
_ROUTEHINT.fields_by_name['hop_hints'].message_type = _HOPHINT
_NETWORK_NAME.containing_type = _NETWORK
_GETNODEINFORESPONSE.fields_by_name['network'].enum_type = _NETWORK_NAME
_LISTCHANNELSRESPONSE.fields_by_name['channels'].message_type = _CHANNEL
_CHANNEL.fields_by_name['state'].enum_type = _CHANNEL_STATE
_CHANNEL_STATE.containing_type = _CHANNEL
_LISTINVOICESREQUEST.fields_by_name['search_order'].enum_type = _ORDER_DIRECTION
_LISTINVOICESREQUEST.fields_by_name['list_order'].enum_type = _ORDER_DIRECTION
_LISTINVOICESRESPONSE.fields_by_name['invoices'].message_type = _INVOICE
_ORDER_DIRECTION.containing_type = _ORDER
_INVOICE.fields_by_name['route_hints'].message_type = _ROUTEHINT
_INVOICE.fields_by_name['state'].enum_type = _INVOICE_STATE
_INVOICE_STATE.containing_type = _INVOICE
_LISTPAYMENTSRESPONSE.fields_by_name['payments'].message_type = _PAYMENT
_LISTPEERSRESPONSE.fields_by_name['peers'].message_type = _PEER
_LISTTRANSACTIONSRESPONSE.fields_by_name['transactions'].message_type = _TRANSACTION
_NEWADDRESSREQUEST.fields_by_name['addr_type'].enum_type = _ADDRESS_TYPE
_ADDRESS_TYPE.containing_type = _ADDRESS
DESCRIPTOR.message_types_by_name['UnlockRequest'] = _UNLOCKREQUEST
DESCRIPTOR.message_types_by_name['UnlockResponse'] = _UNLOCKRESPONSE
DESCRIPTOR.message_types_by_name['GetInfoRequest'] = _GETINFOREQUEST
DESCRIPTOR.message_types_by_name['GetInfoResponse'] = _GETINFORESPONSE
DESCRIPTOR.message_types_by_name['LockRequest'] = _LOCKREQUEST
DESCRIPTOR.message_types_by_name['LockResponse'] = _LOCKRESPONSE
DESCRIPTOR.message_types_by_name['BalanceOffChainRequest'] = _BALANCEOFFCHAINREQUEST
DESCRIPTOR.message_types_by_name['BalanceOffChainResponse'] = _BALANCEOFFCHAINRESPONSE
DESCRIPTOR.message_types_by_name['CheckInvoiceRequest'] = _CHECKINVOICEREQUEST
DESCRIPTOR.message_types_by_name['CheckInvoiceResponse'] = _CHECKINVOICERESPONSE
DESCRIPTOR.message_types_by_name['CloseChannelRequest'] = _CLOSECHANNELREQUEST
DESCRIPTOR.message_types_by_name['CloseChannelResponse'] = _CLOSECHANNELRESPONSE
DESCRIPTOR.message_types_by_name['CreateInvoiceRequest'] = _CREATEINVOICEREQUEST
DESCRIPTOR.message_types_by_name['CreateInvoiceResponse'] = _CREATEINVOICERESPONSE
DESCRIPTOR.message_types_by_name['GetNodeInfoRequest'] = _GETNODEINFOREQUEST
DESCRIPTOR.message_types_by_name['DecodeInvoiceRequest'] = _DECODEINVOICEREQUEST
DESCRIPTOR.message_types_by_name['DecodeInvoiceResponse'] = _DECODEINVOICERESPONSE
DESCRIPTOR.message_types_by_name['RouteHint'] = _ROUTEHINT
DESCRIPTOR.message_types_by_name['HopHint'] = _HOPHINT
DESCRIPTOR.message_types_by_name['Network'] = _NETWORK
DESCRIPTOR.message_types_by_name['GetNodeInfoResponse'] = _GETNODEINFORESPONSE
DESCRIPTOR.message_types_by_name['ListChannelsRequest'] = _LISTCHANNELSREQUEST
DESCRIPTOR.message_types_by_name['ListChannelsResponse'] = _LISTCHANNELSRESPONSE
DESCRIPTOR.message_types_by_name['Channel'] = _CHANNEL
DESCRIPTOR.message_types_by_name['ListInvoicesRequest'] = _LISTINVOICESREQUEST
DESCRIPTOR.message_types_by_name['ListInvoicesResponse'] = _LISTINVOICESRESPONSE
DESCRIPTOR.message_types_by_name['Order'] = _ORDER
DESCRIPTOR.message_types_by_name['Invoice'] = _INVOICE
DESCRIPTOR.message_types_by_name['ListPaymentsRequest'] = _LISTPAYMENTSREQUEST
DESCRIPTOR.message_types_by_name['ListPaymentsResponse'] = _LISTPAYMENTSRESPONSE
DESCRIPTOR.message_types_by_name['Payment'] = _PAYMENT
DESCRIPTOR.message_types_by_name['ListPeersRequest'] = _LISTPEERSREQUEST
DESCRIPTOR.message_types_by_name['ListPeersResponse'] = _LISTPEERSRESPONSE
DESCRIPTOR.message_types_by_name['Peer'] = _PEER
DESCRIPTOR.message_types_by_name['ListTransactionsRequest'] = _LISTTRANSACTIONSREQUEST
DESCRIPTOR.message_types_by_name['ListTransactionsResponse'] = _LISTTRANSACTIONSRESPONSE
DESCRIPTOR.message_types_by_name['Transaction'] = _TRANSACTION
DESCRIPTOR.message_types_by_name['NewAddressRequest'] = _NEWADDRESSREQUEST
DESCRIPTOR.message_types_by_name['NewAddressResponse'] = _NEWADDRESSRESPONSE
DESCRIPTOR.message_types_by_name['Address'] = _ADDRESS
DESCRIPTOR.message_types_by_name['OpenChannelRequest'] = _OPENCHANNELREQUEST
DESCRIPTOR.message_types_by_name['OpenChannelResponse'] = _OPENCHANNELRESPONSE
DESCRIPTOR.message_types_by_name['PayInvoiceRequest'] = _PAYINVOICEREQUEST
DESCRIPTOR.message_types_by_name['PayInvoiceResponse'] = _PAYINVOICERESPONSE
DESCRIPTOR.message_types_by_name['PayOnChainRequest'] = _PAYONCHAINREQUEST
DESCRIPTOR.message_types_by_name['PayOnChainResponse'] = _PAYONCHAINRESPONSE
DESCRIPTOR.message_types_by_name['UnlockNodeRequest'] = _UNLOCKNODEREQUEST
DESCRIPTOR.message_types_by_name['UnlockNodeResponse'] = _UNLOCKNODERESPONSE
DESCRIPTOR.message_types_by_name['BalanceOnChainRequest'] = _BALANCEONCHAINREQUEST
DESCRIPTOR.message_types_by_name['BalanceOnChainResponse'] = _BALANCEONCHAINRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UnlockRequest = _reflection.GeneratedProtocolMessageType('UnlockRequest', (_message.Message,), {
  'DESCRIPTOR' : _UNLOCKREQUEST,
  '__module__' : 'boltlight_proto.boltlight_pb2'
  # @@protoc_insertion_point(class_scope:boltlight.UnlockRequest)
  })
_sym_db.RegisterMessage(UnlockRequest)

UnlockResponse = _reflection.GeneratedProtocolMessageType('UnlockResponse', (_message.Message,), {
  'DESCRIPTOR' : _UNLOCKRESPONSE,
  '__module__' : 'boltlight_proto.boltlight_pb2'
  # @@protoc_insertion_point(class_scope:boltlight.UnlockResponse)
  })
_sym_db.RegisterMessage(UnlockResponse)

GetInfoRequest = _reflection.GeneratedProtocolMessageType('GetInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETINFOREQUEST,
  '__module__' : 'boltlight_proto.boltlight_pb2'
  # @@protoc_insertion_point(class_scope:boltlight.GetInfoRequest)
  })
_sym_db.RegisterMessage(GetInfoRequest)

GetInfoResponse = _reflection.GeneratedProtocolMessageType('GetInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETINFORESPONSE,
  '__module__' : 'boltlight_proto.boltlight_pb2'
  # @@protoc_insertion_point(class_scope:boltlight.GetInfoResponse)
  })
_sym_db.RegisterMessage(GetInfoResponse)

LockRequest = _reflection.GeneratedProtocolMessageType('LockRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOCKREQUEST,
  '__module__' : 'boltlight_proto.boltlight_pb2'
  # @@protoc_insertion_point(class_scope:boltlight.LockRequest)
  })
_sym_db.RegisterMessage(LockRequest)

LockResponse = _reflection.GeneratedProtocolMessageType('LockResponse', (_message.Message,), {
  'DESCRIPTOR' : _LOCKRESPONSE,
  '__module__' : 'boltlight_proto.boltlight_pb2'
  # @@protoc_insertion_point(class_scope:boltlight.LockResponse)
  })
_sym_db.RegisterMessage(LockResponse)

BalanceOffChainRequest = _reflection.GeneratedProtocolMessageType('BalanceOffChainRequest', (_message.Message,), {
  'DESCRIPTOR' : _BALANCEOFFCHAINREQUEST,
  '__module__' : 'boltlight_proto.boltlight_pb2'
  # @@protoc_insertion_point(class_scope:boltlight.BalanceOffChainRequest)
  })
_sym_db.RegisterMessage(BalanceOffChainRequest)

BalanceOffChainResponse = _reflection.GeneratedProtocolMessageType('BalanceOffChainResponse', (_message.Message,), {
  'DESCRIPTOR' : _BALANCEOFFCHAINRESPONSE,
  '__module__' : 'boltlight_proto.boltlight_pb2'
  # @@protoc_insertion_point(class_scope:boltlight.BalanceOffChainResponse)
  })
_sym_db.RegisterMessage(BalanceOffChainResponse)

CheckInvoiceRequest = _reflection.GeneratedProtocolMessageType('CheckInvoiceRequest', (_message.Message,), {
  'DESCRIPTOR' : _CHECKINVOICEREQUEST,
  '__module__' : 'boltlight_proto.boltlight_pb2'
  # @@protoc_insertion_point(class_scope:boltlight.CheckInvoiceRequest)
  })
_sym_db.RegisterMessage(CheckInvoiceRequest)

CheckInvoiceResponse = _reflection.GeneratedProtocolMessageType('CheckInvoiceResponse', (_message.Message,), {
  'DESCRIPTOR' : _CHECKINVOICERESPONSE,
  '__module__' : 'boltlight_proto.boltlight_pb2'
  # @@protoc_insertion_point(class_scope:boltlight.CheckInvoiceResponse)
  })
_sym_db.RegisterMessage(CheckInvoiceResponse)

CloseChannelRequest = _reflection.GeneratedProtocolMessageType('CloseChannelRequest', (_message.Message,), {
  'DESCRIPTOR' : _CLOSECHANNELREQUEST,
  '__module__' : 'boltlight_proto.boltlight_pb2'
  # @@protoc_insertion_point(class_scope:boltlight.CloseChannelRequest)
  })
_sym_db.RegisterMessage(CloseChannelRequest)

CloseChannelResponse = _reflection.GeneratedProtocolMessageType('CloseChannelResponse', (_message.Message,), {
  'DESCRIPTOR' : _CLOSECHANNELRESPONSE,
  '__module__' : 'boltlight_proto.boltlight_pb2'
  # @@protoc_insertion_point(class_scope:boltlight.CloseChannelResponse)
  })
_sym_db.RegisterMessage(CloseChannelResponse)

CreateInvoiceRequest = _reflection.GeneratedProtocolMessageType('CreateInvoiceRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEINVOICEREQUEST,
  '__module__' : 'boltlight_proto.boltlight_pb2'
  # @@protoc_insertion_point(class_scope:boltlight.CreateInvoiceRequest)
  })
_sym_db.RegisterMessage(CreateInvoiceRequest)

CreateInvoiceResponse = _reflection.GeneratedProtocolMessageType('CreateInvoiceResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEINVOICERESPONSE,
  '__module__' : 'boltlight_proto.boltlight_pb2'
  # @@protoc_insertion_point(class_scope:boltlight.CreateInvoiceResponse)
  })
_sym_db.RegisterMessage(CreateInvoiceResponse)

GetNodeInfoRequest = _reflection.GeneratedProtocolMessageType('GetNodeInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNODEINFOREQUEST,
  '__module__' : 'boltlight_proto.boltlight_pb2'
  # @@protoc_insertion_point(class_scope:boltlight.GetNodeInfoRequest)
  })
_sym_db.RegisterMessage(GetNodeInfoRequest)

DecodeInvoiceRequest = _reflection.GeneratedProtocolMessageType('DecodeInvoiceRequest', (_message.Message,), {
  'DESCRIPTOR' : _DECODEINVOICEREQUEST,
  '__module__' : 'boltlight_proto.boltlight_pb2'
  # @@protoc_insertion_point(class_scope:boltlight.DecodeInvoiceRequest)
  })
_sym_db.RegisterMessage(DecodeInvoiceRequest)

DecodeInvoiceResponse = _reflection.GeneratedProtocolMessageType('DecodeInvoiceResponse', (_message.Message,), {
  'DESCRIPTOR' : _DECODEINVOICERESPONSE,
  '__module__' : 'boltlight_proto.boltlight_pb2'
  # @@protoc_insertion_point(class_scope:boltlight.DecodeInvoiceResponse)
  })
_sym_db.RegisterMessage(DecodeInvoiceResponse)

RouteHint = _reflection.GeneratedProtocolMessageType('RouteHint', (_message.Message,), {
  'DESCRIPTOR' : _ROUTEHINT,
  '__module__' : 'boltlight_proto.boltlight_pb2'
  # @@protoc_insertion_point(class_scope:boltlight.RouteHint)
  })
_sym_db.RegisterMessage(RouteHint)

HopHint = _reflection.GeneratedProtocolMessageType('HopHint', (_message.Message,), {
  'DESCRIPTOR' : _HOPHINT,
  '__module__' : 'boltlight_proto.boltlight_pb2'
  # @@protoc_insertion_point(class_scope:boltlight.HopHint)
  })
_sym_db.RegisterMessage(HopHint)

Network = _reflection.GeneratedProtocolMessageType('Network', (_message.Message,), {
  'DESCRIPTOR' : _NETWORK,
  '__module__' : 'boltlight_proto.boltlight_pb2'
  # @@protoc_insertion_point(class_scope:boltlight.Network)
  })
_sym_db.RegisterMessage(Network)

GetNodeInfoResponse = _reflection.GeneratedProtocolMessageType('GetNodeInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETNODEINFORESPONSE,
  '__module__' : 'boltlight_proto.boltlight_pb2'
  # @@protoc_insertion_point(class_scope:boltlight.GetNodeInfoResponse)
  })
_sym_db.RegisterMessage(GetNodeInfoResponse)

ListChannelsRequest = _reflection.GeneratedProtocolMessageType('ListChannelsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCHANNELSREQUEST,
  '__module__' : 'boltlight_proto.boltlight_pb2'
  # @@protoc_insertion_point(class_scope:boltlight.ListChannelsRequest)
  })
_sym_db.RegisterMessage(ListChannelsRequest)

ListChannelsResponse = _reflection.GeneratedProtocolMessageType('ListChannelsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCHANNELSRESPONSE,
  '__module__' : 'boltlight_proto.boltlight_pb2'
  # @@protoc_insertion_point(class_scope:boltlight.ListChannelsResponse)
  })
_sym_db.RegisterMessage(ListChannelsResponse)

Channel = _reflection.GeneratedProtocolMessageType('Channel', (_message.Message,), {
  'DESCRIPTOR' : _CHANNEL,
  '__module__' : 'boltlight_proto.boltlight_pb2'
  # @@protoc_insertion_point(class_scope:boltlight.Channel)
  })
_sym_db.RegisterMessage(Channel)

ListInvoicesRequest = _reflection.GeneratedProtocolMessageType('ListInvoicesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTINVOICESREQUEST,
  '__module__' : 'boltlight_proto.boltlight_pb2'
  # @@protoc_insertion_point(class_scope:boltlight.ListInvoicesRequest)
  })
_sym_db.RegisterMessage(ListInvoicesRequest)

ListInvoicesResponse = _reflection.GeneratedProtocolMessageType('ListInvoicesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTINVOICESRESPONSE,
  '__module__' : 'boltlight_proto.boltlight_pb2'
  # @@protoc_insertion_point(class_scope:boltlight.ListInvoicesResponse)
  })
_sym_db.RegisterMessage(ListInvoicesResponse)

Order = _reflection.GeneratedProtocolMessageType('Order', (_message.Message,), {
  'DESCRIPTOR' : _ORDER,
  '__module__' : 'boltlight_proto.boltlight_pb2'
  # @@protoc_insertion_point(class_scope:boltlight.Order)
  })
_sym_db.RegisterMessage(Order)

Invoice = _reflection.GeneratedProtocolMessageType('Invoice', (_message.Message,), {
  'DESCRIPTOR' : _INVOICE,
  '__module__' : 'boltlight_proto.boltlight_pb2'
  # @@protoc_insertion_point(class_scope:boltlight.Invoice)
  })
_sym_db.RegisterMessage(Invoice)

ListPaymentsRequest = _reflection.GeneratedProtocolMessageType('ListPaymentsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPAYMENTSREQUEST,
  '__module__' : 'boltlight_proto.boltlight_pb2'
  # @@protoc_insertion_point(class_scope:boltlight.ListPaymentsRequest)
  })
_sym_db.RegisterMessage(ListPaymentsRequest)

ListPaymentsResponse = _reflection.GeneratedProtocolMessageType('ListPaymentsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPAYMENTSRESPONSE,
  '__module__' : 'boltlight_proto.boltlight_pb2'
  # @@protoc_insertion_point(class_scope:boltlight.ListPaymentsResponse)
  })
_sym_db.RegisterMessage(ListPaymentsResponse)

Payment = _reflection.GeneratedProtocolMessageType('Payment', (_message.Message,), {
  'DESCRIPTOR' : _PAYMENT,
  '__module__' : 'boltlight_proto.boltlight_pb2'
  # @@protoc_insertion_point(class_scope:boltlight.Payment)
  })
_sym_db.RegisterMessage(Payment)

ListPeersRequest = _reflection.GeneratedProtocolMessageType('ListPeersRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPEERSREQUEST,
  '__module__' : 'boltlight_proto.boltlight_pb2'
  # @@protoc_insertion_point(class_scope:boltlight.ListPeersRequest)
  })
_sym_db.RegisterMessage(ListPeersRequest)

ListPeersResponse = _reflection.GeneratedProtocolMessageType('ListPeersResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPEERSRESPONSE,
  '__module__' : 'boltlight_proto.boltlight_pb2'
  # @@protoc_insertion_point(class_scope:boltlight.ListPeersResponse)
  })
_sym_db.RegisterMessage(ListPeersResponse)

Peer = _reflection.GeneratedProtocolMessageType('Peer', (_message.Message,), {
  'DESCRIPTOR' : _PEER,
  '__module__' : 'boltlight_proto.boltlight_pb2'
  # @@protoc_insertion_point(class_scope:boltlight.Peer)
  })
_sym_db.RegisterMessage(Peer)

ListTransactionsRequest = _reflection.GeneratedProtocolMessageType('ListTransactionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTTRANSACTIONSREQUEST,
  '__module__' : 'boltlight_proto.boltlight_pb2'
  # @@protoc_insertion_point(class_scope:boltlight.ListTransactionsRequest)
  })
_sym_db.RegisterMessage(ListTransactionsRequest)

ListTransactionsResponse = _reflection.GeneratedProtocolMessageType('ListTransactionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTTRANSACTIONSRESPONSE,
  '__module__' : 'boltlight_proto.boltlight_pb2'
  # @@protoc_insertion_point(class_scope:boltlight.ListTransactionsResponse)
  })
_sym_db.RegisterMessage(ListTransactionsResponse)

Transaction = _reflection.GeneratedProtocolMessageType('Transaction', (_message.Message,), {
  'DESCRIPTOR' : _TRANSACTION,
  '__module__' : 'boltlight_proto.boltlight_pb2'
  # @@protoc_insertion_point(class_scope:boltlight.Transaction)
  })
_sym_db.RegisterMessage(Transaction)

NewAddressRequest = _reflection.GeneratedProtocolMessageType('NewAddressRequest', (_message.Message,), {
  'DESCRIPTOR' : _NEWADDRESSREQUEST,
  '__module__' : 'boltlight_proto.boltlight_pb2'
  # @@protoc_insertion_point(class_scope:boltlight.NewAddressRequest)
  })
_sym_db.RegisterMessage(NewAddressRequest)

NewAddressResponse = _reflection.GeneratedProtocolMessageType('NewAddressResponse', (_message.Message,), {
  'DESCRIPTOR' : _NEWADDRESSRESPONSE,
  '__module__' : 'boltlight_proto.boltlight_pb2'
  # @@protoc_insertion_point(class_scope:boltlight.NewAddressResponse)
  })
_sym_db.RegisterMessage(NewAddressResponse)

Address = _reflection.GeneratedProtocolMessageType('Address', (_message.Message,), {
  'DESCRIPTOR' : _ADDRESS,
  '__module__' : 'boltlight_proto.boltlight_pb2'
  # @@protoc_insertion_point(class_scope:boltlight.Address)
  })
_sym_db.RegisterMessage(Address)

OpenChannelRequest = _reflection.GeneratedProtocolMessageType('OpenChannelRequest', (_message.Message,), {
  'DESCRIPTOR' : _OPENCHANNELREQUEST,
  '__module__' : 'boltlight_proto.boltlight_pb2'
  # @@protoc_insertion_point(class_scope:boltlight.OpenChannelRequest)
  })
_sym_db.RegisterMessage(OpenChannelRequest)

OpenChannelResponse = _reflection.GeneratedProtocolMessageType('OpenChannelResponse', (_message.Message,), {
  'DESCRIPTOR' : _OPENCHANNELRESPONSE,
  '__module__' : 'boltlight_proto.boltlight_pb2'
  # @@protoc_insertion_point(class_scope:boltlight.OpenChannelResponse)
  })
_sym_db.RegisterMessage(OpenChannelResponse)

PayInvoiceRequest = _reflection.GeneratedProtocolMessageType('PayInvoiceRequest', (_message.Message,), {
  'DESCRIPTOR' : _PAYINVOICEREQUEST,
  '__module__' : 'boltlight_proto.boltlight_pb2'
  # @@protoc_insertion_point(class_scope:boltlight.PayInvoiceRequest)
  })
_sym_db.RegisterMessage(PayInvoiceRequest)

PayInvoiceResponse = _reflection.GeneratedProtocolMessageType('PayInvoiceResponse', (_message.Message,), {
  'DESCRIPTOR' : _PAYINVOICERESPONSE,
  '__module__' : 'boltlight_proto.boltlight_pb2'
  # @@protoc_insertion_point(class_scope:boltlight.PayInvoiceResponse)
  })
_sym_db.RegisterMessage(PayInvoiceResponse)

PayOnChainRequest = _reflection.GeneratedProtocolMessageType('PayOnChainRequest', (_message.Message,), {
  'DESCRIPTOR' : _PAYONCHAINREQUEST,
  '__module__' : 'boltlight_proto.boltlight_pb2'
  # @@protoc_insertion_point(class_scope:boltlight.PayOnChainRequest)
  })
_sym_db.RegisterMessage(PayOnChainRequest)

PayOnChainResponse = _reflection.GeneratedProtocolMessageType('PayOnChainResponse', (_message.Message,), {
  'DESCRIPTOR' : _PAYONCHAINRESPONSE,
  '__module__' : 'boltlight_proto.boltlight_pb2'
  # @@protoc_insertion_point(class_scope:boltlight.PayOnChainResponse)
  })
_sym_db.RegisterMessage(PayOnChainResponse)

UnlockNodeRequest = _reflection.GeneratedProtocolMessageType('UnlockNodeRequest', (_message.Message,), {
  'DESCRIPTOR' : _UNLOCKNODEREQUEST,
  '__module__' : 'boltlight_proto.boltlight_pb2'
  # @@protoc_insertion_point(class_scope:boltlight.UnlockNodeRequest)
  })
_sym_db.RegisterMessage(UnlockNodeRequest)

UnlockNodeResponse = _reflection.GeneratedProtocolMessageType('UnlockNodeResponse', (_message.Message,), {
  'DESCRIPTOR' : _UNLOCKNODERESPONSE,
  '__module__' : 'boltlight_proto.boltlight_pb2'
  # @@protoc_insertion_point(class_scope:boltlight.UnlockNodeResponse)
  })
_sym_db.RegisterMessage(UnlockNodeResponse)

BalanceOnChainRequest = _reflection.GeneratedProtocolMessageType('BalanceOnChainRequest', (_message.Message,), {
  'DESCRIPTOR' : _BALANCEONCHAINREQUEST,
  '__module__' : 'boltlight_proto.boltlight_pb2'
  # @@protoc_insertion_point(class_scope:boltlight.BalanceOnChainRequest)
  })
_sym_db.RegisterMessage(BalanceOnChainRequest)

BalanceOnChainResponse = _reflection.GeneratedProtocolMessageType('BalanceOnChainResponse', (_message.Message,), {
  'DESCRIPTOR' : _BALANCEONCHAINRESPONSE,
  '__module__' : 'boltlight_proto.boltlight_pb2'
  # @@protoc_insertion_point(class_scope:boltlight.BalanceOnChainResponse)
  })
_sym_db.RegisterMessage(BalanceOnChainResponse)


_ADDRESS_TYPE._options = None

_UNLOCKER = _descriptor.ServiceDescriptor(
  name='Unlocker',
  full_name='boltlight.Unlocker',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=4279,
  serialized_end=4352,
  methods=[
  _descriptor.MethodDescriptor(
    name='Unlock',
    full_name='boltlight.Unlocker.Unlock',
    index=0,
    containing_service=None,
    input_type=_UNLOCKREQUEST,
    output_type=_UNLOCKRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_UNLOCKER)

DESCRIPTOR.services_by_name['Unlocker'] = _UNLOCKER


_BOLTLIGHT = _descriptor.ServiceDescriptor(
  name='Boltlight',
  full_name='boltlight.Boltlight',
  file=DESCRIPTOR,
  index=1,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=4355,
  serialized_end=4489,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetInfo',
    full_name='boltlight.Boltlight.GetInfo',
    index=0,
    containing_service=None,
    input_type=_GETINFOREQUEST,
    output_type=_GETINFORESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Lock',
    full_name='boltlight.Boltlight.Lock',
    index=1,
    containing_service=None,
    input_type=_LOCKREQUEST,
    output_type=_LOCKRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_BOLTLIGHT)

DESCRIPTOR.services_by_name['Boltlight'] = _BOLTLIGHT


_LIGHTNING = _descriptor.ServiceDescriptor(
  name='Lightning',
  full_name='boltlight.Lightning',
  file=DESCRIPTOR,
  index=2,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=4492,
  serialized_end=5874,
  methods=[
  _descriptor.MethodDescriptor(
    name='BalanceOffChain',
    full_name='boltlight.Lightning.BalanceOffChain',
    index=0,
    containing_service=None,
    input_type=_BALANCEOFFCHAINREQUEST,
    output_type=_BALANCEOFFCHAINRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='BalanceOnChain',
    full_name='boltlight.Lightning.BalanceOnChain',
    index=1,
    containing_service=None,
    input_type=_BALANCEONCHAINREQUEST,
    output_type=_BALANCEONCHAINRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CheckInvoice',
    full_name='boltlight.Lightning.CheckInvoice',
    index=2,
    containing_service=None,
    input_type=_CHECKINVOICEREQUEST,
    output_type=_CHECKINVOICERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CloseChannel',
    full_name='boltlight.Lightning.CloseChannel',
    index=3,
    containing_service=None,
    input_type=_CLOSECHANNELREQUEST,
    output_type=_CLOSECHANNELRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateInvoice',
    full_name='boltlight.Lightning.CreateInvoice',
    index=4,
    containing_service=None,
    input_type=_CREATEINVOICEREQUEST,
    output_type=_CREATEINVOICERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DecodeInvoice',
    full_name='boltlight.Lightning.DecodeInvoice',
    index=5,
    containing_service=None,
    input_type=_DECODEINVOICEREQUEST,
    output_type=_DECODEINVOICERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetNodeInfo',
    full_name='boltlight.Lightning.GetNodeInfo',
    index=6,
    containing_service=None,
    input_type=_GETNODEINFOREQUEST,
    output_type=_GETNODEINFORESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListChannels',
    full_name='boltlight.Lightning.ListChannels',
    index=7,
    containing_service=None,
    input_type=_LISTCHANNELSREQUEST,
    output_type=_LISTCHANNELSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListInvoices',
    full_name='boltlight.Lightning.ListInvoices',
    index=8,
    containing_service=None,
    input_type=_LISTINVOICESREQUEST,
    output_type=_LISTINVOICESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListPayments',
    full_name='boltlight.Lightning.ListPayments',
    index=9,
    containing_service=None,
    input_type=_LISTPAYMENTSREQUEST,
    output_type=_LISTPAYMENTSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListPeers',
    full_name='boltlight.Lightning.ListPeers',
    index=10,
    containing_service=None,
    input_type=_LISTPEERSREQUEST,
    output_type=_LISTPEERSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListTransactions',
    full_name='boltlight.Lightning.ListTransactions',
    index=11,
    containing_service=None,
    input_type=_LISTTRANSACTIONSREQUEST,
    output_type=_LISTTRANSACTIONSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='NewAddress',
    full_name='boltlight.Lightning.NewAddress',
    index=12,
    containing_service=None,
    input_type=_NEWADDRESSREQUEST,
    output_type=_NEWADDRESSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OpenChannel',
    full_name='boltlight.Lightning.OpenChannel',
    index=13,
    containing_service=None,
    input_type=_OPENCHANNELREQUEST,
    output_type=_OPENCHANNELRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PayInvoice',
    full_name='boltlight.Lightning.PayInvoice',
    index=14,
    containing_service=None,
    input_type=_PAYINVOICEREQUEST,
    output_type=_PAYINVOICERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PayOnChain',
    full_name='boltlight.Lightning.PayOnChain',
    index=15,
    containing_service=None,
    input_type=_PAYONCHAINREQUEST,
    output_type=_PAYONCHAINRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UnlockNode',
    full_name='boltlight.Lightning.UnlockNode',
    index=16,
    containing_service=None,
    input_type=_UNLOCKNODEREQUEST,
    output_type=_UNLOCKNODERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_LIGHTNING)

DESCRIPTOR.services_by_name['Lightning'] = _LIGHTNING

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['boltlight_proto']

package_data = \
{'': ['*']}

install_requires = \
['grpcio>=1.43.0,<2.0.0', 'protobuf>=3.19.1,<4.0.0']

setup_kwargs = {
    'name': 'boltlight-proto',
    'version': '2.0.0',
    'description': 'Protobuf generated libraries for Boltlight',
    'long_description': None,
    'author': 'Hashbeam',
    'author_email': 'hashbeam@protonmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://gitlab.com/hashbeam/boltlight-proto',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7.0,<4.0.0',
}


setup(**setup_kwargs)
